@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.4.  */
+/* A Bison parser, made by GNU Bison 3.4.1.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.4"
+#define YYBISON_VERSION "3.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -67,8 +71,8 @@
 #define yynerrs         cql_nerrs
 
 
-/* Copy the first part of user declarations.  */
-#line 6 "cql.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 6 "cql.y"
 
 /**
  * \file cql.c
@@ -123,13 +127,17 @@ int yylex(YYSTYPE *lval, void *vp);
 int yyerror(void *lval, char *msg);
 
 
-#line 127 "cql.c" /* yacc.c:339  */
+#line 131 "cql.c"
 
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -194,9 +202,7 @@ int cql_parse (void *parm);
 
 
 
-/* Copy the second part of user declarations.  */
 
-#line 200 "cql.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -217,13 +223,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -235,7 +241,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -271,15 +277,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -287,7 +284,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -307,6 +304,8 @@ typedef short int yytype_int16;
 #endif
 
 
+#define YY_ASSERT(E) ((void) (0 && (E)))
+
 #if ! defined yyoverflow || YYERROR_VERBOSE
 
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
@@ -449,16 +448,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  66
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   268
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -658,22 +657,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (parm, YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (parm, YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -713,38 +712,38 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, void *parm)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, void *parm)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   YYUSE (parm);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep, void *parm)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep, void *parm)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep, parm);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep, parm);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -778,7 +777,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, void *parm)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -789,7 +788,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule, void *parm)
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               , parm);
       YYFPRINTF (stderr, "\n");
     }
@@ -893,7 +892,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -911,7 +913,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -989,10 +991,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1004,6 +1006,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1015,9 +1018,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1148,23 +1152,33 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+  YY_ASSERT (0 <= yystate && yystate < YYNSTATES);
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1180,14 +1194,10 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1203,35 +1213,33 @@ YYSTYPE yylval YY_INITIAL_VALUE (= yyval_default);
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
-
-  YYDPRINTF ((stderr, "Entering state %d\n", yystate));
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   if (yystate == YYFINAL)
     YYACCEPT;
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1289,7 +1297,6 @@ yybackup:
   YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN
   *++yyvsp = yylval;
   YY_IGNORE_MAYBE_UNINITIALIZED_END
-
   goto yynewstate;
 
 
@@ -1304,7 +1311,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1324,233 +1331,234 @@ yyreduce:
   YY_REDUCE_PRINT (yyn);
   switch (yyn)
     {
-        case 2:
-#line 69 "cql.y" /* yacc.c:1646  */
+  case 2:
+#line 69 "cql.y"
     {
-    (yyval).rel = cql_node_mk_sc(((CQL_parser) parm)->nmem,
+    yyval.rel = cql_node_mk_sc(((CQL_parser) parm)->nmem,
 			    "cql.serverChoice", "=", 0);
     ((CQL_parser) parm)->top = 0;
 }
-#line 1335 "cql.c" /* yacc.c:1646  */
+#line 1342 "cql.c"
     break;
 
   case 3:
-#line 73 "cql.y" /* yacc.c:1646  */
+#line 73 "cql.y"
     {
-    cql_node_destroy((yyval).rel);
-    if ((yyvsp[0]).cql)
+    cql_node_destroy(yyval.rel);
+    if (yyvsp[0].cql)
     {
-        (yyvsp[0]).cql->u.sort.search = (yyvsp[-1]).cql;
-        ((CQL_parser) parm)->top = (yyvsp[0]).cql;
+        yyvsp[0].cql->u.sort.search = yyvsp[-1].cql;
+        ((CQL_parser) parm)->top = yyvsp[0].cql;
     } else {
-        ((CQL_parser) parm)->top = (yyvsp[-1]).cql;
+        ((CQL_parser) parm)->top = yyvsp[-1].cql;
     }
 }
-#line 1350 "cql.c" /* yacc.c:1646  */
+#line 1357 "cql.c"
     break;
 
   case 4:
-#line 86 "cql.y" /* yacc.c:1646  */
-    { (yyval).cql = 0; }
-#line 1356 "cql.c" /* yacc.c:1646  */
+#line 86 "cql.y"
+    { yyval.cql = 0; }
+#line 1363 "cql.c"
     break;
 
   case 5:
-#line 87 "cql.y" /* yacc.c:1646  */
+#line 87 "cql.y"
     {
-    (yyval).cql = (yyvsp[0]).cql;
+    yyval.cql = yyvsp[0].cql;
  }
-#line 1364 "cql.c" /* yacc.c:1646  */
+#line 1371 "cql.c"
     break;
 
   case 6:
-#line 91 "cql.y" /* yacc.c:1646  */
+#line 91 "cql.y"
     {
-    (yyval).cql = (yyvsp[-1]).cql;
-    (yyval).cql->u.sort.next = (yyvsp[0]).cql;
+    yyval.cql = yyvsp[-1].cql;
+    yyval.cql->u.sort.next = yyvsp[0].cql;
  }
-#line 1373 "cql.c" /* yacc.c:1646  */
+#line 1380 "cql.c"
     break;
 
   case 7:
-#line 96 "cql.y" /* yacc.c:1646  */
+#line 96 "cql.y"
     {
-    (yyval).cql = (yyvsp[0]).cql;
+    yyval.cql = yyvsp[0].cql;
 }
-#line 1381 "cql.c" /* yacc.c:1646  */
+#line 1388 "cql.c"
     break;
 
   case 8:
-#line 100 "cql.y" /* yacc.c:1646  */
+#line 100 "cql.y"
     {
-    (yyval).cql = cql_node_mk_sort(((CQL_parser) parm)->nmem, (yyvsp[-1]).buf, (yyvsp[0]).cql);
+    yyval.cql = cql_node_mk_sort(((CQL_parser) parm)->nmem, yyvsp[-1].buf, yyvsp[0].cql);
  }
-#line 1389 "cql.c" /* yacc.c:1646  */
+#line 1396 "cql.c"
     break;
 
   case 10:
-#line 106 "cql.y" /* yacc.c:1646  */
+#line 106 "cql.y"
     {
-    cql_node_destroy((yyvsp[-1]).cql);
-    (yyval).cql = 0;
+    cql_node_destroy(yyvsp[-1].cql);
+    yyval.cql = 0;
 }
-#line 1398 "cql.c" /* yacc.c:1646  */
+#line 1405 "cql.c"
     break;
 
   case 12:
-#line 115 "cql.y" /* yacc.c:1646  */
+#line 115 "cql.y"
     {
-    (yyval).rel = (yyvsp[-4]).rel;
+    yyval.rel = yyvsp[-4].rel;
   }
-#line 1406 "cql.c" /* yacc.c:1646  */
+#line 1413 "cql.c"
     break;
 
   case 13:
-#line 117 "cql.y" /* yacc.c:1646  */
+#line 117 "cql.y"
     {
-    (yyval).cql = cql_apply_prefix(((CQL_parser) parm)->nmem,
-			      (yyvsp[0]).cql, (yyvsp[-4]).buf, (yyvsp[-2]).buf);
+    yyval.cql = cql_apply_prefix(((CQL_parser) parm)->nmem,
+			      yyvsp[0].cql, yyvsp[-4].buf, yyvsp[-2].buf);
   }
-#line 1415 "cql.c" /* yacc.c:1646  */
+#line 1422 "cql.c"
     break;
 
   case 14:
-#line 121 "cql.y" /* yacc.c:1646  */
+#line 121 "cql.y"
     {
-      (yyval).rel = (yyvsp[-2]).rel;
+      yyval.rel = yyvsp[-2].rel;
   }
-#line 1423 "cql.c" /* yacc.c:1646  */
+#line 1430 "cql.c"
     break;
 
   case 15:
-#line 123 "cql.y" /* yacc.c:1646  */
+#line 123 "cql.y"
     {
-    (yyval).cql = cql_apply_prefix(((CQL_parser) parm)->nmem,
-			      (yyvsp[0]).cql, 0, (yyvsp[-2]).buf);
+    yyval.cql = cql_apply_prefix(((CQL_parser) parm)->nmem,
+			      yyvsp[0].cql, 0, yyvsp[-2].buf);
    }
-#line 1432 "cql.c" /* yacc.c:1646  */
+#line 1439 "cql.c"
     break;
 
   case 17:
-#line 132 "cql.y" /* yacc.c:1646  */
+#line 132 "cql.y"
     {
-      (yyval).rel = (yyvsp[-3]).rel;
+      yyval.rel = yyvsp[-3].rel;
   }
-#line 1440 "cql.c" /* yacc.c:1646  */
+#line 1447 "cql.c"
     break;
 
   case 18:
-#line 134 "cql.y" /* yacc.c:1646  */
+#line 134 "cql.y"
     {
       struct cql_node *cn = cql_node_mk_boolean(((CQL_parser) parm)->nmem,
-						(yyvsp[-3]).buf);
+						yyvsp[-3].buf);
 
-      cn->u.boolean.modifiers = (yyvsp[-2]).cql;
-      cn->u.boolean.left = (yyvsp[-4]).cql;
-      cn->u.boolean.right = (yyvsp[0]).cql;
+      cn->u.boolean.modifiers = yyvsp[-2].cql;
+      cn->u.boolean.left = yyvsp[-4].cql;
+      cn->u.boolean.right = yyvsp[0].cql;
 
-      (yyval).cql = cn;
+      yyval.cql = cn;
   }
-#line 1455 "cql.c" /* yacc.c:1646  */
+#line 1462 "cql.c"
     break;
 
   case 19:
-#line 147 "cql.y" /* yacc.c:1646  */
+#line 147 "cql.y"
     {
-      (yyval).rel = (yyvsp[-1]).rel;
+      yyval.rel = yyvsp[-1].rel;
 
   }
-#line 1464 "cql.c" /* yacc.c:1646  */
+#line 1471 "cql.c"
     break;
 
   case 20:
-#line 150 "cql.y" /* yacc.c:1646  */
+#line 150 "cql.y"
     {
-      (yyval).cql = (yyvsp[-1]).cql;
+      yyval.cql = yyvsp[-1].cql;
   }
-#line 1472 "cql.c" /* yacc.c:1646  */
+#line 1479 "cql.c"
     break;
 
   case 21:
-#line 154 "cql.y" /* yacc.c:1646  */
+#line 154 "cql.y"
     {
-      struct cql_node *st = cql_node_dup(((CQL_parser) parm)->nmem, (yyvsp[-2]).rel);
-      st->u.st.extra_terms = (yyvsp[0]).cql;
-      st->u.st.term = nmem_strdup(((CQL_parser)parm)->nmem, (yyvsp[-1]).buf);
-      (yyval).cql = st;
+      struct cql_node *st = cql_node_dup(((CQL_parser) parm)->nmem, yyvsp[-2].rel);
+      st->u.st.extra_terms = yyvsp[0].cql;
+      st->u.st.term = nmem_strdup(((CQL_parser)parm)->nmem, yyvsp[-1].buf);
+      yyval.cql = st;
   }
-#line 1483 "cql.c" /* yacc.c:1646  */
+#line 1490 "cql.c"
     break;
 
   case 22:
-#line 161 "cql.y" /* yacc.c:1646  */
+#line 161 "cql.y"
     {
-      (yyval).rel = cql_node_mk_sc(((CQL_parser) parm)->nmem, (yyvsp[-2]).buf, (yyvsp[-1]).buf, 0);
-      (yyval).rel->u.st.modifiers = (yyvsp[0]).cql;
+      yyval.rel = cql_node_mk_sc(((CQL_parser) parm)->nmem, yyvsp[-2].buf, yyvsp[-1].buf, 0);
+      yyval.rel->u.st.modifiers = yyvsp[0].cql;
   }
-#line 1492 "cql.c" /* yacc.c:1646  */
+#line 1499 "cql.c"
     break;
 
   case 23:
-#line 164 "cql.y" /* yacc.c:1646  */
+#line 164 "cql.y"
     {
-      (yyval).cql = (yyvsp[0]).cql;
-      cql_node_destroy((yyvsp[-1]).rel);
+      yyval.cql = yyvsp[0].cql;
+      cql_node_destroy(yyvsp[-1].rel);
   }
-#line 1501 "cql.c" /* yacc.c:1646  */
+#line 1508 "cql.c"
     break;
 
   case 24:
-#line 171 "cql.y" /* yacc.c:1646  */
+#line 171 "cql.y"
     {
     struct cql_node *st = cql_node_mk_sc(((CQL_parser) parm)->nmem,
-					 /* index */ 0, /* rel */ 0, (yyvsp[-1]).buf);
-    st->u.st.extra_terms = (yyvsp[0]).cql;
-    (yyval).cql = st;
+					 /* index */ 0, /* rel */ 0, yyvsp[-1].buf);
+    st->u.st.extra_terms = yyvsp[0].cql;
+    yyval.cql = st;
 }
-#line 1512 "cql.c" /* yacc.c:1646  */
+#line 1519 "cql.c"
     break;
 
   case 25:
-#line 178 "cql.y" /* yacc.c:1646  */
-    { (yyval).cql = 0; }
-#line 1518 "cql.c" /* yacc.c:1646  */
+#line 178 "cql.y"
+    { yyval.cql = 0; }
+#line 1525 "cql.c"
     break;
 
   case 30:
-#line 188 "cql.y" /* yacc.c:1646  */
+#line 188 "cql.y"
     {
     struct cql_node *mod = cql_node_mk_sc(((CQL_parser)parm)->nmem,
-					  (yyvsp[0]).buf, 0, 0);
+					  yyvsp[0].buf, 0, 0);
 
-    mod->u.st.modifiers = (yyvsp[-2]).cql;
-    (yyval).cql = mod;
+    mod->u.st.modifiers = yyvsp[-2].cql;
+    yyval.cql = mod;
 }
-#line 1530 "cql.c" /* yacc.c:1646  */
+#line 1537 "cql.c"
     break;
 
   case 31:
-#line 197 "cql.y" /* yacc.c:1646  */
+#line 197 "cql.y"
     {
     struct cql_node *mod = cql_node_mk_sc(((CQL_parser)parm)->nmem,
-					  (yyvsp[-2]).buf, (yyvsp[-1]).buf, (yyvsp[0]).buf);
+					  yyvsp[-2].buf, yyvsp[-1].buf, yyvsp[0].buf);
 
-    mod->u.st.modifiers = (yyvsp[-4]).cql;
-    (yyval).cql = mod;
+    mod->u.st.modifiers = yyvsp[-4].cql;
+    yyval.cql = mod;
 }
-#line 1542 "cql.c" /* yacc.c:1646  */
+#line 1549 "cql.c"
     break;
 
   case 32:
-#line 205 "cql.y" /* yacc.c:1646  */
+#line 205 "cql.y"
     {
-    (yyval).cql = 0;
+    yyval.cql = 0;
 }
-#line 1550 "cql.c" /* yacc.c:1646  */
+#line 1557 "cql.c"
     break;
 
 
-#line 1554 "cql.c" /* yacc.c:1646  */
+#line 1561 "cql.c"
+
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1575,14 +1583,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1665,12 +1672,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1732,6 +1737,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1739,6 +1745,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1749,6 +1756,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
@@ -1778,7 +1789,7 @@ yyreturn:
 #endif
   return yyresult;
 }
-#line 235 "cql.y" /* yacc.c:1906  */
+#line 235 "cql.y"
 
 
 int yyerror(void *locp, char *s)
